#define _CRT_SECURE_NO_DEPRECATE
#define _CRT_SECURE_NO_WARNINGS
#define _USE_MATH_DEFINES

#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <iomanip>
#include <fstream>
#include <cmath>
#include <cstring>
#include <ctime>
#include <cassert>
#include <memory.h>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <unordered_set>
#include <unordered_map>
#include <queue>
#include <utility>
#include <algorithm>
#include <functional>
#include <complex>
#include <bitset>
#include <random>

using namespace std;

typedef long long int64;
typedef unsigned long long uint64;
typedef pair<int, int> pii;
typedef pair<int64, int64> pll;
const int INF = (int)(1e9 + 1e5);
const int64 LINF = (int64)(4e18);
const double EPS = 1e-9;
#define sq(x) ((x)*(x))
#define FAIL() ((*(int*)0)++)

bool le(const double &a, const double &b)
{
	return a < b - EPS;
}

bool leq(const double &a, const double &b)
{
	return a < b + EPS;
}

bool eq(const double &a, const double &b)
{
	return fabs(a - b) < EPS;
}

bool greq(const double &a, const double &b)
{
	return a > b - EPS;
}

bool gr(const double &a, const double &b)
{
	return a > b + EPS;
}

const double PI = acos(-1);
struct dot
{
	double x, y;
	dot() {}
	dot(double x, double y) : x(x), y(y) {}
	dot turn(double a) const
	{
		dot res;
		res.x = x * cos(a) - y * sin(a);
		res.y = x * sin(a) + y * cos(a);
		return res;
	}
	double len() const
	{
		return sqrt(sq(x) + sq(y));
	}
};

dot operator+(const dot &a, const dot &b)
{
	return dot(a.x + b.x, a.y + b.y);
}

dot operator-(const dot &a, const dot &b)
{
	return dot(a.x - b.x, a.y - b.y);
}

dot operator*(const dot &a, const double &b)
{
	return dot(a.x * b, a.y * b);
}

dot operator/(const dot &a, const double &b)
{
	return dot(a.x / b, a.y / b);
}

bool operator==(const dot &a, const dot &b)
{
	return fabs(a.x - b.x) < EPS && fabs(a.y - b.y) < EPS;
}

double delta(double a, double b)
{
	double res = fabs(a - b);
	while (res < 0)
		res += 2.0 * PI;
	while (res > 2.0 * PI)
		res -= 2.0 * PI;
	return min(res, 2.0 * PI - res);
}

bool operator<(const dot &a, const dot &b)
{
	double a1 = atan2(a.y, a.x);
	double a2 = atan2(b.y, b.x);
	if (fabs(delta(a1, a2)) > EPS)
		return a1 < a2;
	else
		return a.len() < b.len();
}

int n;
dot a[1010];
dot ta[1010];
dot b[1010];
dot tb[1010];

void norm(dot a[])
{
	dot mid(0, 0);
	for (int i = 0; i < n; i++)
	{
		mid.x += a[i].x;
		mid.y += a[i].y;
	}
	mid = mid / n;
	for (int i = 0; i < n; i++)
	{
		a[i] = a[i] - mid;
	}
}

void turnall(dot a[], dot ta[], double dt)
{
	for (int i = 0; i < n; i++)
	{
		ta[i] = a[i].turn(-dt);
	}
}

void solve()
{
	cin >> n;
	mt19937 gen(1337);
	uniform_real_distribution<double> distr(-PI, PI);
	double buben = distr(gen);
	for (int i = 0; i < n; i++)
	{
		cin >> a[i].x >> a[i].y;
		a[i].turn(buben);
	}
	for (int i = 0; i < n; i++)
	{
		cin >> b[i].x >> b[i].y;
		b[i].turn(buben);
	}
	norm(a);
	norm(b);
	sort(a, a + n);
	sort(b, b + n);
	double ans = 1e18;
	for (int i = 0; i < n; i++)
	{
		for (int j = i; j < n; j++)
		{
			double a1 = atan2(a[i].y, a[i].x);
			double a2 = atan2(b[j].y, b[j].x);
			double tans = delta(a1, a2);
			if (greq(tans, ans))
				continue;
			//turnall(a, ta, a1);
			//turnall(b, tb, a2);
			int ti = i;
			int tj = j;
			bool was = false;
			for (int k = 0; k < n && !was; k++)
			{
				dot ta, tb;
				ta = a[ti].turn(-a1);
				tb = b[tj].turn(-a2);
				ti++;
				if (ti == n)
					ti = 0;
				tj++;
				if (tj == n)
					tj = 0;
				if (!eq(ta.x, tb.x) || !eq(ta.y, tb.y))
					was = true;
			}
			if (!was)
				ans = tans;
		}
	}
	cout.precision(15);
	cout << fixed << ans;
}

int main()
{
	ios_base::sync_with_stdio(false); cin.tie(0);
#ifdef _MY_DEBUG
	freopen("input.txt", "rt", stdin); freopen("output.txt", "wt", stdout);
#else
#endif

	solve();

	return 0;
}