#include <bits/stdc++.h>

using namespace std;

#define double long double

const double pi = acos(-1);
const double eps = 1e-11;

typedef complex<double> point;
#define X real()
#define Y imag()

bool cmp(point a, point b) {
    if (b.X - a.X > eps) return true;
    if (a.X - b.X > eps) return false;
    return a.Y < b.Y;
}

bool is_equal(point a, point b) {
    return fabs(a.X - b.X) < eps && fabs(a.Y - b.Y) < eps;
}

double check(vector<point> a, vector<point> b, point A, point B, point C, point D) {
    int n = a.size();
    point rot = (B - D) / (A - C);
    point shift = B - A * rot;
    for (int i = 0; i < n; ++i) {
        a[i] = a[i] * rot + shift;
    }
    sort(a.begin(), a.end(), cmp);
    sort(b.begin(), b.end(), cmp);
    for (int i = 0; i < n; ++i) {
        if (!is_equal(a[i], b[i])) {
            return 100500;
        }
    }
    double tmp = arg(rot);
    if (tmp < -eps) tmp += 2 * pi;
    if (tmp < 0) tmp = 0;
    return tmp;
}

double cross(point A, point B, point C) {
    point v = B - A;
    point u = B - C;
    return v.X * u.Y - v.Y * u.X;
}

vector<point> convex_hull(vector<point> a) {
    vector<point> ans;
    sort(a.begin(), a.end(), cmp);
    for (int q = 0; q < 2; ++q) {
        int start = ans.size();
        for (auto i: a) {
            while (ans.size() >= start + 2) {
                point A = ans[ans.size() - 2];
                point B = ans.back();
                if (cross(A, B, i) > eps) {
                    ans.pop_back();
                } else {
                    break;
                }
            }
            ans.push_back(i);
        }
        ans.pop_back();
        reverse(a.begin(), a.end());
    }
    return ans;
}

point get_center(const vector<point> &a) {
    vector<point> hull = convex_hull(a);
    int n = hull.size();
    double k = 1.0 / n;
    point ans = 0;
    for (int i = 0; i < n; ++i) {
        ans += hull[i] * k;
    }
    return ans;
}

bool all_equals(const vector<point> &a) {
    for (int i = 0; i < a.size(); ++i) {
        if (!is_equal(a[i], a[0])) {
            return false;
        }
    }
    return true;
}

signed main() {
    ios_base::sync_with_stdio(false); cin.tie(0);
    cout << fixed; cout.precision(12);

    double ans = 100500;

    int n;
    cin >> n;
    vector<point> a;
    for (int i = 0; i < n; ++i) {
        double x, y; cin >> x >> y;
        a.push_back({x, y});
    }
    vector<point> b;
    for (int i = 0; i < n; ++i) {
        double x, y; cin >> x >> y;
        b.push_back({x, y});
    }
    if (all_equals(a)) {
        cout << 0;
        return 0;
    }

    point first_center = get_center(a);
    point second_center = get_center(b);
    for (int i = 0; i < n; ++i) {
        if (is_equal(a[i], first_center)) continue;
        for (int j = 0; j < n; ++j) {
            if (is_equal(b[j], second_center)) continue;
            ans = min(ans, check(a, b, first_center, second_center, a[i], b[j]));
        }
        break;
    }
    cout << ans << endl;
}

